@@ -29,7 +29,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <QStyleOption>
 #include <QTimer>
 
-#include <knotification.h>
+#include <KNotification>
 
 #include "kcalc_core.h"
 #include "kcalc_settings.h"
@@ -1023,5 +1023,5 @@ QSize KCalcDisplay::sizeHint() const {
 	QStyleOptionFrame option;
 	initStyleOption(&option);
 
-	return (style()->sizeFromContents(QStyle::CT_LineEdit, &option, sz.expandedTo(QApplication::globalStrut()),	this));
+	return (style()->sizeFromContents(QStyle::CT_LineEdit, &option, sz,	this));
 }
